##  Introduction
Archiving fact sheets keeps your workspace organized and efficient by removing outdated or duplicate fact sheets. This helps improve system performance, makes important data easier to find, and supports better resource management.
When a fact sheet is archived, it is removed from the default inventory list. The fact sheet is not permanently deleted immediately; instead, it remains recoverable for 90 days. During this retention period, you can access and recover archived fact sheets at any time if needed. After the retention period, the archived fact sheet is automatically and permanently deleted with no possibility of recovery.
Maintaining the lifecycle data is recommended to actively manage records of decommissioned applications. This ensures that the relations of the archived fact sheets remain visible and that they are still included in reports.
**Tip**
Pricing Implications: Archived application fact sheets do not count for pricing.
